@@ -1,4 +1,5 @@
 """Kernel gateway managers."""
+
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
 from __future__ import annotations
@@ -313,7 +314,7 @@ class GatewayKernelSpecManager(KernelSpecManager):
         try:
             response = await gateway_request(kernel_spec_url, method="GET")
         except web.HTTPError as error:
-            if error.status_code == 404:  # noqa: PLR2004
+            if error.status_code == 404:
                 # Convert not found to KeyError since that's what the Notebook handler expects
                 # message is not used, but might as well make it useful for troubleshooting
                 msg = f"kernelspec {kernel_name} not found on Gateway server at: {GatewayClient.instance().url}"
@@ -342,7 +343,7 @@ class GatewayKernelSpecManager(KernelSpecManager):
         try:
             response = await gateway_request(kernel_spec_resource_url, method="GET")
         except web.HTTPError as error:
-            if error.status_code == 404:  # noqa: PLR2004
+            if error.status_code == 404:
                 kernel_spec_resource = None
             else:
                 raise
@@ -368,7 +369,7 @@ class GatewaySessionManager(SessionManager):
             # Note that should the redundant polling be consolidated, or replaced with an event-based
             # notification model, this will need to be revisited.
             km = self.kernel_manager.get_kernel(kernel_id)
-        except Exception:  # noqa
+        except Exception:
             # Let exceptions here reflect culled kernel
             pass
         return km is None
@@ -439,7 +440,7 @@ class GatewayKernelManager(ServerKernelManager):
                 response = await gateway_request(self.kernel_url, method="GET")
 
             except web.HTTPError as error:
-                if error.status_code == 404:  # noqa: PLR2004
+                if error.status_code == 404:
                     self.log.warning("Kernel not found at: %s" % self.kernel_url)
                     model = None
                 else:
@@ -533,7 +534,7 @@ class GatewayKernelManager(ServerKernelManager):
                 response = await gateway_request(self.kernel_url, method="DELETE")
                 self.log.debug("Shutdown kernel response: %d %s", response.code, response.reason)
             except web.HTTPError as error:
-                if error.status_code == 404:  # noqa: PLR2004
+                if error.status_code == 404:
                     self.log.debug("Shutdown kernel response: kernel not found (ignored)")
                 else:
                     raise
@@ -585,7 +586,6 @@ class GatewayKernelManager(ServerKernelManager):
 
     def cleanup_resources(self, restart=False):
         """Clean up resources when the kernel is shut down"""
-        pass
 
 
 KernelManagerABC.register(GatewayKernelManager)
@@ -656,7 +656,6 @@ class ChannelQueue(Queue):  # type:ignore[type-arg]
 
     def start(self) -> None:
         """Start the queue."""
-        pass
 
     def stop(self) -> None:
         """Stop the queue."""
@@ -673,9 +672,7 @@ class ChannelQueue(Queue):  # type:ignore[type-arg]
                 return
             if len(msgs):
                 self.log.warning(
-                    "Stopping channel '{}' with {} unprocessed non-status messages: {}.".format(
-                        self.channel_name, len(msgs), msgs
-                    )
+                    f"Stopping channel '{self.channel_name}' with {len(msgs)} unprocessed non-status messages: {msgs}."
                 )
 
     def is_alive(self) -> bool:
