@@ -1,4 +1,5 @@
 """A contents manager that uses the local file system for storage."""
+
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
 from __future__ import annotations
@@ -268,6 +269,8 @@ class FileContentsManager(FileManagerMixin, ContentsManager):
         model["mimetype"] = None
         model["size"] = size
         model["writable"] = self.is_writable(path)
+        model["hash"] = None
+        model["hash_algorithm"] = None
 
         return model
 
@@ -335,7 +338,7 @@ class FileContentsManager(FileManagerMixin, ContentsManager):
 
         return model
 
-    def _file_model(self, path, content=True, format=None):
+    def _file_model(self, path, content=True, format=None, require_hash=False):
         """Build a model for a file
 
         if content is requested, include the file contents.
@@ -344,6 +347,8 @@ class FileContentsManager(FileManagerMixin, ContentsManager):
           If 'text', the contents will be decoded as UTF-8.
           If 'base64', the raw bytes contents will be encoded as base64.
           If not specified, try to decode as UTF-8, and fall back to base64
+
+        if require_hash is true, the model will include 'hash'
         """
         model = self._base_model(path)
         model["type"] = "file"
@@ -351,8 +356,9 @@ class FileContentsManager(FileManagerMixin, ContentsManager):
         os_path = self._get_os_path(path)
         model["mimetype"] = mimetypes.guess_type(os_path)[0]
 
+        bytes_content = None
         if content:
-            content, format = self._read_file(os_path, format)
+            content, format, bytes_content = self._read_file(os_path, format, raw=True)  # type: ignore[misc]
             if model["mimetype"] is None:
                 default_mime = {
                     "text": "text/plain",
@@ -365,31 +371,44 @@ class FileContentsManager(FileManagerMixin, ContentsManager):
                 format=format,
             )
 
+        if require_hash:
+            if bytes_content is None:
+                bytes_content, _ = self._read_file(os_path, "byte")  # type: ignore[assignment,misc]
+            model.update(**self._get_hash(bytes_content))  # type: ignore[arg-type]
+
         return model
 
-    def _notebook_model(self, path, content=True):
+    def _notebook_model(self, path, content=True, require_hash=False):
         """Build a notebook model
 
         if content is requested, the notebook content will be populated
         as a JSON structure (not double-serialized)
+
+        if require_hash is true, the model will include 'hash'
         """
         model = self._base_model(path)
         model["type"] = "notebook"
         os_path = self._get_os_path(path)
 
+        bytes_content = None
         if content:
             validation_error: dict[str, t.Any] = {}
-            nb = self._read_notebook(
-                os_path, as_version=4, capture_validation_error=validation_error
+            nb, bytes_content = self._read_notebook(
+                os_path, as_version=4, capture_validation_error=validation_error, raw=True
             )
             self.mark_trusted_cells(nb, path)
             model["content"] = nb
             model["format"] = "json"
             self.validate_notebook_model(model, validation_error)
 
+        if require_hash:
+            if bytes_content is None:
+                bytes_content, _ = self._read_file(os_path, "byte")  # type: ignore[misc]
+            model.update(**self._get_hash(bytes_content))  # type: ignore[arg-type]
+
         return model
 
-    def get(self, path, content=True, type=None, format=None):
+    def get(self, path, content=True, type=None, format=None, require_hash=False):
         """Takes a path for an entity and returns its model
 
         Parameters
@@ -404,6 +423,8 @@ class FileContentsManager(FileManagerMixin, ContentsManager):
         format : str, optional
             The requested format for file contents. 'text' or 'base64'.
             Ignored if this returns a notebook or directory model.
+        require_hash: bool, optional
+            Whether to include the hash of the file contents.
 
         Returns
         -------
@@ -431,11 +452,13 @@ class FileContentsManager(FileManagerMixin, ContentsManager):
                 )
             model = self._dir_model(path, content=content)
         elif type == "notebook" or (type is None and path.endswith(".ipynb")):
-            model = self._notebook_model(path, content=content)
+            model = self._notebook_model(path, content=content, require_hash=require_hash)
         else:
             if type == "directory":
                 raise web.HTTPError(400, "%s is not a directory" % path, reason="bad type")
-            model = self._file_model(path, content=content, format=format)
+            model = self._file_model(
+                path, content=content, format=format, require_hash=require_hash
+            )
         self.emit(data={"action": "get", "path": path})
         return model
 
@@ -686,7 +709,9 @@ class FileContentsManager(FileManagerMixin, ContentsManager):
                 ).stdout.split()
             else:
                 result = subprocess.run(
-                    ["du", "-s", "--block-size=1", path], capture_output=True, check=True
+                    ["du", "-s", "--block-size=1", path],
+                    capture_output=True,
+                    check=True,
                 ).stdout.split()
 
             self.log.info(f"current status of du command {result}")
@@ -784,7 +809,7 @@ class AsyncFileContentsManager(FileContentsManager, AsyncFileManagerMixin, Async
 
         return model
 
-    async def _file_model(self, path, content=True, format=None):
+    async def _file_model(self, path, content=True, format=None, require_hash=False):
         """Build a model for a file
 
         if content is requested, include the file contents.
@@ -793,6 +818,8 @@ class AsyncFileContentsManager(FileContentsManager, AsyncFileManagerMixin, Async
           If 'text', the contents will be decoded as UTF-8.
           If 'base64', the raw bytes contents will be encoded as base64.
           If not specified, try to decode as UTF-8, and fall back to base64
+
+        if require_hash is true, the model will include 'hash'
         """
         model = self._base_model(path)
         model["type"] = "file"
@@ -800,8 +827,9 @@ class AsyncFileContentsManager(FileContentsManager, AsyncFileManagerMixin, Async
         os_path = self._get_os_path(path)
         model["mimetype"] = mimetypes.guess_type(os_path)[0]
 
+        bytes_content = None
         if content:
-            content, format = await self._read_file(os_path, format)
+            content, format, bytes_content = await self._read_file(os_path, format, raw=True)  # type: ignore[misc]
             if model["mimetype"] is None:
                 default_mime = {
                     "text": "text/plain",
@@ -814,9 +842,14 @@ class AsyncFileContentsManager(FileContentsManager, AsyncFileManagerMixin, Async
                 format=format,
             )
 
+        if require_hash:
+            if bytes_content is None:
+                bytes_content, _ = await self._read_file(os_path, "byte")  # type: ignore[assignment,misc]
+            model.update(**self._get_hash(bytes_content))  # type: ignore[arg-type]
+
         return model
 
-    async def _notebook_model(self, path, content=True):
+    async def _notebook_model(self, path, content=True, require_hash=False):
         """Build a notebook model
 
         if content is requested, the notebook content will be populated
@@ -826,19 +859,25 @@ class AsyncFileContentsManager(FileContentsManager, AsyncFileManagerMixin, Async
         model["type"] = "notebook"
         os_path = self._get_os_path(path)
 
+        bytes_content = None
         if content:
             validation_error: dict[str, t.Any] = {}
-            nb = await self._read_notebook(
-                os_path, as_version=4, capture_validation_error=validation_error
+            nb, bytes_content = await self._read_notebook(
+                os_path, as_version=4, capture_validation_error=validation_error, raw=True
             )
             self.mark_trusted_cells(nb, path)
             model["content"] = nb
             model["format"] = "json"
             self.validate_notebook_model(model, validation_error)
 
+        if require_hash:
+            if bytes_content is None:
+                bytes_content, _ = await self._read_file(os_path, "byte")  # type: ignore[misc]
+            model.update(**(self._get_hash(bytes_content)))  # type: ignore[arg-type]
+
         return model
 
-    async def get(self, path, content=True, type=None, format=None):
+    async def get(self, path, content=True, type=None, format=None, require_hash=False):
         """Takes a path for an entity and returns its model
 
         Parameters
@@ -853,6 +892,8 @@ class AsyncFileContentsManager(FileContentsManager, AsyncFileManagerMixin, Async
         format : str, optional
             The requested format for file contents. 'text' or 'base64'.
             Ignored if this returns a notebook or directory model.
+        require_hash: bool, optional
+            Whether to include the hash of the file contents.
 
         Returns
         -------
@@ -875,11 +916,13 @@ class AsyncFileContentsManager(FileContentsManager, AsyncFileManagerMixin, Async
                 )
             model = await self._dir_model(path, content=content)
         elif type == "notebook" or (type is None and path.endswith(".ipynb")):
-            model = await self._notebook_model(path, content=content)
+            model = await self._notebook_model(path, content=content, require_hash=require_hash)
         else:
             if type == "directory":
                 raise web.HTTPError(400, "%s is not a directory" % path, reason="bad type")
-            model = await self._file_model(path, content=content, format=format)
+            model = await self._file_model(
+                path, content=content, format=format, require_hash=require_hash
+            )
         self.emit(data={"action": "get", "path": path})
         return model
 
@@ -983,7 +1026,7 @@ class AsyncFileContentsManager(FileContentsManager, AsyncFileManagerMixin, Async
             try:
                 send2trash(os_path)
             except OSError as e:
-                raise web.HTTPError(400, "send2trash f`1ailed: %s" % e) from e
+                raise web.HTTPError(400, "send2trash failed: %s" % e) from e
             return
 
         if os.path.isdir(os_path):
@@ -1147,7 +1190,9 @@ class AsyncFileContentsManager(FileContentsManager, AsyncFileManagerMixin, Async
                 ).stdout.split()
             else:
                 result = subprocess.run(
-                    ["du", "-s", "--block-size=1", path], capture_output=True, check=True
+                    ["du", "-s", "--block-size=1", path],
+                    capture_output=True,
+                    check=True,
                 ).stdout.split()
 
             self.log.info(f"current status of du command {result}")
