@@ -3,6 +3,7 @@
 - raises HTTPErrors
 - creates REST API models
 """
+
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
 from __future__ import annotations
@@ -373,7 +374,7 @@ class MappingKernelManager(MultiKernelManager):
         """
         self.log.debug("Getting buffer for %s", kernel_id)
         if kernel_id not in self._kernel_buffers:
-            return
+            return None
 
         buffer_info = self._kernel_buffers[kernel_id]
         if buffer_info["session_key"] == session_key:
@@ -802,7 +803,7 @@ class ServerKernelManager(AsyncIOLoopKernelManager):
 
     # This trait is intended for subclasses to override and define
     # custom event schemas.
-    extra_event_schema_paths: List[str] = List(  # type:ignore[assignment]
+    extra_event_schema_paths: List[str] = List(
         default_value=[],
         help="""
         A list of pathlib.Path objects pointing at to register with
