@@ -1,4 +1,5 @@
 """Tornado handlers for the terminal emulator."""
+
 # Copyright (c) Jupyter Development Team.
 # Distributed under the terms of the Modified BSD License.
-from jupyter_server_terminals.handlers import TermSocket  # noqa
+from jupyter_server_terminals.handlers import TermSocket
